DevSettings class

Available extensions
Annotations
  • @serializable

Constructors

DevSettings(bool? appBuildRunner)

Properties

appBuildRunner → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic f(DevSettingsBuilder b)) → DevSettings

Available on DevSettings, provided by the DevSettingsDogsExtension extension

toBuilder() → DevSettingsBuilder

Available on DevSettings, provided by the DevSettingsDogsExtension extension

toNative() → Map<String, dynamic>

Available on DevSettings, provided by the DevSettingsDogsExtension extension

toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited